@@ -140,7 +140,7 @@ class MList(list):
         self._update_delta()
 
     def __getitem__(self, idx):
-        result = dict.__getitem__(self, idx)
+        result = list.__getitem__(self, idx)
         if isinstance(result, list):
             result = MList(result, self, idx)
         if isinstance(result, dict):
